/* ---------------------------------------------------------------------
 * month_day converts a yearday 'y' (in the range 0-365) into the triple
 * year/month/day, coded after Kernighan/Ritchie :-)
 * compile with
 *      cc -s -o month_day month_day.c
 * ---------------------------------------------------------------------
 * This file is a part of tcharge, version 1.3, 11MAY98
 * Copyright (C) 1997,98 Volker B"orchers (boercher@physik.uni-bremen.de)
 * See file `tcharge.c' for legal affairs.
 */

#include <stdio.h>
#include <stdlib.h>


#define USE "Usage: month_day <year> <yearday>\n <yearday> has range 0-365\
\nExample: month_day 1997 364\n"

int main(int argc, char *argv[])
{
  char **check=NULL;
  int i, date[2], leap;
  int day_tab[2][13] = {
    {0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31},
    {0, 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31}
  };

  if(argc != 3) {
    fprintf(stderr, "(Stop) Wrong number of arguments.\n%s", USE);
    return 1;
  }
  for(i=0; i<2; i++) {
    date[i] = (int) strtoul(argv[i+1], check, 10);
    if (check != NULL) {
      fprintf(stderr, "(Stop) Cannot convert string \"%s\" to integer.\n%s",
	      argv[i+1], USE);
      return 1;
    }
  }
  if(date[0] < 100) {
    fprintf(stderr, "(Stop) Year (here %i) must be fully specified (1997 not 97)!\n%s",
	    date[0], USE);
    return 1;
  }
  if(date[1] < 0 || date[1] > 365) {
    fprintf(stderr, "(Stop) Yeardays (here %i) in range 0 to 365!\n%s",
	    date[0], USE);
    return 1;
  }
  leap = ((date[0]) % 4 == 0 && ((date[0]) % 100 != 0 || (date[0]) % 400 == 0));
  for(i=1; date[1] > day_tab[leap][i]; i++)
    date[1] -= day_tab[leap][i];
  printf("year/month/day = %2i/%02i/%02i\n", date[0], i, date[1]+1);

  return 0;
}
